@@ -910,25 +910,6 @@ PHPAPI pcre2_code *pcre_get_compiled_regex(zend_string *regex, uint32_t *capture
 }
 /* }}} */
 
-/* {{{ pcre_get_compiled_regex_ex */
-PHPAPI pcre2_code* pcre_get_compiled_regex_ex(zend_string *regex, uint32_t *capture_count, uint32_t *preg_options, uint32_t *compile_options)
-{
-	pcre_cache_entry * pce = pcre_get_compiled_regex_cache(regex);
-
-	if (preg_options) {
-		*preg_options = pce ? pce->preg_options : 0;
-	}
-	if (compile_options) {
-		*compile_options = pce ? pce->compile_options : 0;
-	}
-	if (capture_count) {
-		*capture_count = pce ? pce->capture_count : 0;
-	}
-
-	return pce ? pce->re : NULL;
-}
-/* }}} */
-
 /* XXX For the cases where it's only about match yes/no and no capture
 		required, perhaps just a minimum sized data would suffice. */
 PHPAPI pcre2_match_data *php_pcre_create_match_data(uint32_t capture_count, pcre2_code *re)
@@ -1135,11 +1116,6 @@ static void php_do_pcre_match(INTERNAL_FUNCTION_PARAMETERS, int global) /* {{{ *
 		RETURN_FALSE;
 	}
 
-	if (start_offset == ZEND_LONG_MIN) {
-		zend_argument_value_error(5, "must be greater than " ZEND_LONG_FMT, ZEND_LONG_MIN);
-		RETURN_THROWS();
-	}
-
 	pce->refcount++;
 	php_pcre_match_impl(pce, subject, return_value, subpats,
 		global, ZEND_NUM_ARGS() >= 4, flags, start_offset);
@@ -1747,11 +1723,9 @@ matched:
 						}
 						if (preg_get_backref(&walk, &backref)) {
 							if (backref < count) {
-								if (offsets[backref<<1] < SIZE_MAX) {
-									match_len = offsets[(backref<<1)+1] - offsets[backref<<1];
-									memcpy(walkbuf, subject + offsets[backref<<1], match_len);
-									walkbuf += match_len;
-								}
+								match_len = offsets[(backref<<1)+1] - offsets[backref<<1];
+								memcpy(walkbuf, subject + offsets[backref<<1], match_len);
+								walkbuf += match_len;
 							}
 							continue;
 						}
